====
calh
====


.. image:: https://img.shields.io/pypi/v/calh.svg
        :target: https://pypi.python.org/pypi/calh

.. image:: https://img.shields.io/travis/ricky-lim/calh.svg
        :target: https://travis-ci.com/ricky-lim/calh

.. image:: https://readthedocs.org/projects/calh/badge/?version=latest
        :target: https://calh.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/badge/python-3.6-blue.svg
 :target: https://www.python.org/downloads/release/python-360/
 :alt: python3.6

.. image:: https://img.shields.io/badge/python-3.7-blue.svg
 :target: https://www.python.org/downloads/release/python-370/
 :alt: python3.6

.. image:: https://pyup.io/repos/github/ricky-lim/calh/shield.svg
     :target: https://pyup.io/repos/github/ricky-lim/calh/
     :alt: Updates

.. image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/ricky-lim/calh/master?filepath=examples%2Fexample.ipynb



Calendar Heatmap

Inspired by `voila_spotify
<https://github.com/voila-gallery/voila-spotify>`_, to create a heatmap for calendar data.

You could check out the example, `here
<https://mybinder.org/v2/gh/ricky-lim/calh/master?filepath=examples%2Fexample.ipynb>`_.

* Free software: Apache Software License 2.0
* Documentation: https://calh.readthedocs.io.


Features
--------

* Filtering calendar
* Visualizing calendar

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
